#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import Iterator
from typing import TYPE_CHECKING
from typing import Optional

from pywintypes import com_error

from pycatia.exception_handling import CATIAApplicationException
from pycatia.knowledge_interfaces.angle import Angle
from pycatia.knowledge_interfaces.bool_param import BoolParam
from pycatia.knowledge_interfaces.dimension import Dimension
from pycatia.knowledge_interfaces.enum_param import EnumParam
from pycatia.knowledge_interfaces.int_param import IntParam
from pycatia.knowledge_interfaces.length import Length
from pycatia.knowledge_interfaces.list_parameter import ListParameter
from pycatia.knowledge_interfaces.parameter import Parameter
from pycatia.knowledge_interfaces.real_param import RealParam
from pycatia.knowledge_interfaces.str_param import StrParam
from pycatia.knowledge_interfaces.units import Units
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant
from pycatia.types.general import any_parameter

if TYPE_CHECKING:
    from pycatia.knowledge_interfaces.parameter_set import ParameterSet

NAME_TO_PYTHON_CLASS_MAPPING = {
    "Parameter": Parameter,
    "EnumParam": EnumParam,
    "BoolParam": BoolParam,
    "IntParam": IntParam,
    "ListParameter": ListParameter,
    "RealParam": RealParam,
    "Dimension": Dimension,
    "Angle": Angle,
    "Length": Length,
    "StrParam": StrParam
}


def parse_to_parameter_subtype(com_object):
    try:
        com_class_name = com_object._oleobj_.GetTypeInfo().GetDocumentation(-1)[0]
        return NAME_TO_PYTHON_CLASS_MAPPING[com_class_name](com_object)
    except (AttributeError, KeyError, com_error, IndexError):
        # Fallback: if something goes wrong above try parsing based on Value
        try:
            if com_object.ValueList is not None:
                return ListParameter(com_object)
        except AttributeError:
            pass

        try:
            if isinstance(com_object.Value, bool):
                return BoolParam(com_object)

            if isinstance(com_object.Value, int):
                return IntParam(com_object)

            if isinstance(com_object.Value, str):
                return StrParam(com_object)

            if isinstance(com_object.Value, float):
                return RealParam(com_object)
        except AttributeError:
            # Parameter has no Value either
            pass

        return Parameter(com_object)


class Parameters(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     Parameters
                | 
                | Represents the Parameters collection of the part or the
                | product.
                | The following example shows how to retrieve it:
                | 
                | 	Dim CATDocs As Documents
                |  Set CATDocs = CATIA.Documents
                |  Dim part1 As Document
                |  Set part1   = CATDocs.Add("CATPart")
                |  Dim parameterList As Parameters
                |   Set parameterList = part1.Part.Parameters

    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=Parameter)
        self.parameters = com_object

    @property
    def root_parameter_set(self) -> 'ParameterSet':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property RootParameterSet() As ParameterSet (Read Only)
                | 
                |     Returns the root parameter set of a document. If it doesn't exist, it is
                |     created.

        :rtype: ParameterSet
        """
        from pycatia.knowledge_interfaces.parameter_set import ParameterSet
        return ParameterSet(self.parameters.RootParameterSet)

    @property
    def units(self) -> Units:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Units() As Units (Read Only)
                | 
                |     Returns the collection of units.

        :rtype: Units
        """

        return Units(self.parameters.Units)

    def all_parameters(self):
        """
        :return: list(Parameter())
        """

        parameters = []

        if self.has_parameters():
            for i in range(self.parameters.Count):
                para = parse_to_parameter_subtype(self.parameters.Item(i + 1))
                parameters.append(para)

        return parameters

    def create_boolean(self, i_name: str, i_value: bool) -> BoolParam:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func CreateBoolean(CATBSTR iName,
                | boolean iValue) As BoolParam
                | 
                |     Creates a boolean parameter and adds it to the part's collection of
                |     parameters.
                | 
                |     Parameters:
                | 
                |         iName
                |             The parameter name 
                |         iValue
                |             The parameter value 
                | 
                |     Example:
                |         This example creates the checked boolean parameter and adds it to the
                |         newly created part:
                | 
                |         Dim CATDocs As Documents
                |          Set CATDocs = CATIA.Documents
                |          Dim part1 As Document
                |          Set part1   = CATDocs.Add("CATPart")
                |          Dim chk As BooleanParam
                |           Set chk = part1.Part.Parameters.CreateBoolean ("checked", False)

        :param str i_name:
        :param bool i_value:
        :rtype: BoolParam
        """
        return BoolParam(self.parameters.CreateBoolean(i_name, i_value))

    def create_dimension(self, i_name: str, i_magnitude: str, i_value: float) -> Dimension:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func CreateDimension(CATBSTR iName,
                | CATBSTR iMagnitude,
                | double iValue) As Dimension
                | 
                |     Creates a user dimension and adds it to the part's collection of
                |     parameters.
                | 
                |     Parameters:
                | 
                |         iName
                |             The dimension name 
                |         iMagnitude
                |             The dimension magnitude. Units are those of the IS system. Valid
                |             magnitudes are:
                | 
                |                 "LENGTH": the unit is the meter.
                |                 "ANGLE": the unit is the radian. 
                | 
                |         The Dimension object provides the Dimension.ValuateFromString method with
                |         which you may express the value in any unit for a given dimension (see the
                |         example below). 
                |     iValue
                |         The dimension value provided as a real number 
                |     Example:
                |         This example creates a LENGTH dimension and adds it to the newly
                |         created part. The initial value is expressed in meters. The new value is
                |         expressed in millimeters.
                | 
                |          Dim depth As Dimension
                |          Set depth = parameters.CreateDimension("depth", "LENGTH", 20)
                |          depth.ValuateFromString("300mm");

        The documentation from the CHM file is incomplete here as many more
        magnitude types are available. For example: TIME, MASS, VOLUME,
        DENSITY, AREA ... If you need to find the magnitude value for the
        dimension type you wish to create use the macro recorder and
        manually create the parameter. The macro script generated will
        reveal the magnitude value required.

        :param str i_name:
        :param str i_magnitude:
        :param float i_value:
        :rtype: Dimension
        """
        com_object = self.parameters.CreateDimension(i_name, i_magnitude, i_value)
        if i_magnitude.lower() == "angle":
            return Angle(com_object)
        if i_magnitude.lower() == "length":
            return Length(com_object)
        return Dimension(com_object)

    def create_integer(self, i_name: str, i_value: int) -> IntParam:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func CreateInteger(CATBSTR iName,
                | long iValue) As IntParam
                | 
                |     Creates an integer parameter and adds it to the part's collection of
                |     parameters.
                | 
                |     Parameters:
                | 
                |         iName
                |             The parameter name 
                |         iValue
                |             The parameter value 
                | 
                |     Example:
                |         This example creates the RevisionNumber integer parameter and adds it
                |         to the newly created part:
                | 
                |         Dim CATDocs As Documents
                |          Set CATDocs = CATIA.Documents
                |          Dim part1 As Document
                |          Set part1   = CATDocs.Add("CATPart")
                |          Dim revision As IntParam
                |           Set revision = part1.Part.Parameters.CreateInteger ("RevisionRumber", 17)

        :param str i_name:
        :param int i_value:
        :rtype: IntParam
        """
        return IntParam(self.parameters.CreateInteger(i_name, i_value))

    def create_list(self, i_name: str) -> ListParameter:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func CreateList(CATBSTR iName) As ListParameter
                | 
                |     Creates a list parameter and adds it to the part's collection of
                |     parameters.
                | 
                |     Parameters:
                | 
                |         iName
                |             The parameter name 
                | 
                |     Example:
                |         This example creates the ListName list parameter and adds it to the
                |         newly created part:
                | 
                |           Set CATDocs = CATIA.Documents
                |           Set part1   = CATDocs.Add("CATPart")
                |           Set list1 = part1.Part.Parameters.CreateList ("ListName")

        :param str i_name:
        :rtype: ListParameter
        """
        return ListParameter(self.parameters.CreateList(i_name))

    def create_real(self, i_name: str, i_value: float) -> RealParam:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func CreateReal(CATBSTR iName,
                | double iValue) As RealParam
                | 
                |     Creates a real parameter and adds it to the part's collection of
                |     parameters.
                | 
                |     Parameters:
                | 
                |         iName
                |             The parameter name 
                |         iValue
                |             The parameter value 
                | 
                |     Example:
                |         This example creates the ReliabilityRate real parameter and adds it to
                |         the newly created part:
                | 
                |         Dim CATDocs As Documents
                |          Set CATDocs = CATIA.Documents
                |          Dim part1 As Document
                |          Set part1   = CATDocs.Add("CATPart")
                |          Dim rate As RealParam
                |           Set rate = part1.Part.Parameters.CreateReal ("ReliabilityRate", 2.5 )

        :param str i_name:
        :param float i_value:
        :rtype: RealParam
        """
        return RealParam(self.parameters.CreateReal(i_name, i_value))

    def create_set_of_parameters(self, i_father: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub CreateSetOfParameters(AnyObject iFather)
                | 
                |     Creates a set of parameters and appends it to argument iFather.

        :param AnyObject i_father:
        :rtype: None
        """
        return self.parameters.CreateSetOfParameters(i_father.com_object)

    def create_string(self, i_name: str, i_value: str) -> StrParam:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func CreateString(CATBSTR iName,
                | CATBSTR iValue) As StrParam
                | 
                |     Creates a string parameter and adds it to the part's collection of
                |     parameters.
                | 
                |     Parameters:
                | 
                |         iName
                |             The parameter name 
                |         iValue
                |             The parameter value 
                | 
                |     Example:
                |         This example creates the responsible string parameter and adds it to
                |         the newly created part:
                | 
                |           Set CATDocs = CATIA.Documents
                |           Set part1   = CATDocs.Add("CATPart")
                |           Set density = part1.Part.Parameters.CreateString ("responsible", "The Boss")

        :param str i_name:
        :param str i_value:
        :rtype: StrParam
        """
        return StrParam(self.parameters.CreateString(i_name, i_value))

    def get_name_to_use_in_relation(self, i_object: AnyObject) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetNameToUseInRelation(AnyObject iObject) As CATBSTR
                | 
                |     Returns a correct name of a feature to use it in a relation.

        :param AnyObject i_object:
        :rtype: str
        """
        return self.parameters.GetNameToUseInRelation(i_object.com_object)

    def has_parameters(self):
        """
        :return: bool
        """
        if self.parameters.Count > 0:
            return True

        return False

    def is_parameter(self, index: cat_variant):
        """
        :param cat_variant index: parameter name or parameter number
        :rtype: bool
        """
        try:
            if self.parameters.Item(index):
                return True
        except com_error:
            return False

    def is_list_parameter(self, index: cat_variant):
        """
        :param cat_variant index: parameter name or parameter number
        :return: bool
        :rtype: bool
        """
        try:
            if self.parameters.Item(index).ValueList:
                return True
        except AttributeError:
            return False

    def item(self, index: cat_variant) -> any_parameter:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic help
                | Item
                | o Func Item(    CATVariant    iIndex) As Parameter
                |
                | Retrieves a parameter  using its index or its name from the from the
                | Parameters collection.
                | Parameters:
                | iIndex
                |    The index or the name of the parameter to retrieve from
                |    the collection of parameters.
                |    As a numeric, this index is the rank of the parameter
                |    in the collection.
                |    The index of the first parameter in the collection is 1, and
                |    the index of the last parameter is Count.
                |    As a string, it is the name you assigned to the parameter using
                |    the
                |
                |  activateLinkAnchor('AnyObject','Name','AnyObject.Name')  property or when
                |  creating the parameter.
                | Examples:
                | This example retrieves the last parameter in the parameters
                | collection:
                |
                | Set lastParameter = parameters.Item(parameters.Count)


        :param cat_variant index:
        :rtype: any_parameter
        """

        if not self.is_parameter(index):
            raise CATIAApplicationException(f'Could not find parameter name "{index}".')

        return parse_to_parameter_subtype(self.parameters.Item(index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes a parameter from the Parameters collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the parameter to remove from the
                |             collection of parameters. As a numerics, this index is the rank of the
                |             parameter in the collection. The index of the first parameter in the collection
                |             is 1, and the index of the last parameter is Count. As a string, it is the name
                |             you assigned to the parameter using the 
                | 
                |         AnyObject.Name property or when creating the parameter.
                |         
                |     Example:
                |         This example removes the "depth" parameter from the parameters
                |         collection.
                | 
                |          parameters.Remove("depth")

        :param cat_variant i_index:
        :rtype: None
        """
        return self.parameters.Remove(i_index)

    def sub_list(self, i_object: AnyObject, i_recursively: bool) -> 'Parameters':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func SubList(AnyObject iObject,
                | boolean iRecursively) As Parameters
                | 
                |     Returns a sub-collection of parameters aggregated to an
                |     object.
                | 
                |     Parameters:
                | 
                |         iObject
                |             The object used to filter the whole parameter collection to get the
                |             resulting sub-collection. 
                |         iRecursively
                |             A flag to specify if children parameters are to be searched for in
                |             the returned collection 
                |         Example:
                |             This example shows how to retrieve a collection of parameters that
                |             are associated to a Pad.
                | 
                |              Dim Parameters1 As Parameters
                |              Set Parameters1 = CATIA.ActiveDocument.Part.Parameters gets the collection of parameters
                |                  in the part
                |              Dim Body0 As AnyObject
                |              Set Body0 = CATIA.ActiveDocument.Part.Bodies.Item  ( "MechanicalTool.1" ) 
                |              Dim Pad1 As AnyObject
                |              Set Pad1 = Body0.Shapes.Item  ( "Pad.1" ) gets the pad Pad.1
                |              Dim Parameters2 As Parameters
                |              Set Parameters2 = Parameters1.SubList(Pad1,TRUE) gets the collection of parameters that
                |                  are under the pad Pad.1

        :param AnyObject i_object:
        :param bool i_recursively:
        :rtype: Parameters
        """
        return Parameters(self.parameters.SubList(i_object.com_object, i_recursively))

    def __getitem__(self, n: int) -> Parameter:
        if (n + 1) > self.count:
            raise StopIteration

        return parse_to_parameter_subtype(self.parameters.Item(n + 1))

    def __iter__(self) -> Iterator[Parameter]:
        for i in range(self.count):
            yield parse_to_parameter_subtype(self.com_object.Item(i + 1))

    def __repr__(self):
        return f'Parameters(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import Iterator

from pycatia.in_interfaces.window import Window
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class Windows(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     Windows
                | 
                | A collection of all the Window objects currently managed by the
                | application.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=Window)
        self.windows = com_object

    def arrange(self, i_style: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub Arrange(CatArrangeStyle iStyle)
                | 
                |     Arranges all the windows of the collection.
                | 
                |     Parameters:
                | 
                |         iStyle
                |             The arrangement style to take into account to arrange the windows
                |             
                | 
                |     Example:
                |         The following example arranges all the windows in the Windows
                |         collection, according to the catArrangeCascade style.
                | 
                |          CATIA.Windows.Arrange(catArrangeCascade)

        :param int i_style: enum cat_arrange_style
        :rtype: None
        """
        return self.windows.Arrange(i_style)

    def item(self, i_index: cat_variant) -> Window:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func Item(CATVariant iIndex) As Window
                | 
                |     Returns a window using its index or its name from the Windows
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the window to retrieve from the collection
                |             of windows. As a numerics, this index is the rank of the window in the
                |             collection. The index of the first window in the collection is 1, and the index
                |             of the last window is Count. As a string, it is the name you assigned to the
                |             window using the 
                | 
                |         AnyObject.Name property. 
                |     Returns:
                |         The retrieved window 
                |     Example:
                |         This example returns in ThisWindow the third window in the collection,
                |         and in ThatWindow the window named MyWindow.
                | 
                |          Dim ThisWindow As Window
                |          Set ThisWindow = CATIA.Windows.Item(3)
                |          Dim ThatWindow As Window
                |          Set ThatWindow = CATIA.Windows.Item("MyWindow")

        :param cat_variant i_index:
        :rtype: Window
        """
        return Window(self.windows.Item(i_index))

    def __getitem__(self, n: int) -> Window:
        if (n + 1) > self.count:
            raise StopIteration

        return Window(self.windows.Item(n + 1))

    def __iter__(self) -> Iterator[Window]:
        for i in range(self.count):
            yield self.child_object(self.com_object.Item(i + 1))

    def __repr__(self):
        return f'Windows(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import TYPE_CHECKING

from pycatia.analysis_interfaces.analysis_color_map import AnalysisColorMap
from pycatia.in_interfaces.folder import Folder
from pycatia.in_interfaces.reference import Reference
from pycatia.mec_mod_interfaces.axis_system import AxisSystem
from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.types.general import cat_variant

if TYPE_CHECKING:
    from pycatia.analysis_interfaces.analysis_images import AnalysisImages


class AnalysisImage(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     AnalysisImage
                | 
                | Represents the analysis image object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.analysis_image = com_object

    @property
    def analysis_color_map(self) -> AnalysisColorMap:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AnalysisColorMap() As AnalysisColorMap (Read Only)
                | 
                |     Returns the color map object associated with an analysis image.

        :rtype: AnalysisColorMap
        """

        return AnalysisColorMap(self.analysis_image.AnalysisColorMap)

    @property
    def analysis_images(self) -> 'AnalysisImages':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AnalysisImages() As AnalysisImages (Read Only)
                | 
                |     Returns the analysis images collection associated with an analysis image.

        :rtype: AnalysisImages
        """

        from pycatia.analysis_interfaces.analysis_images import AnalysisImages
        return AnalysisImages(self.analysis_image.AnalysisImages)

    def export_data(self, i_folder: Folder, i_file_name: str, i_extension_type: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ExportData(Folder iFolder,
                | CATBSTR iFileName,
                | CATBSTR iExtensionType)
                | 
                |     Extracts image results.
                |     The export is done related to an existing image and will be stored in a
                |     CATIA Folder as a Text file or as an Excel file.
                |     Limitations:
                | 
                |         The allowed output positions are: node, element, center of element, and
                |         node of element
                |         The allowed values are: integer, real or double
                |         The allowed value types are: average or discontinuous iso, symbol,
                |         fringe or text
                | 
                |     To export data with mesh-part identification use
                |     ExportDataWithMeshPartId
                | 
                |     Parameters:
                | 
                |         iFolder
                |             The folder to store the file to create 
                |         iFileName
                |             The name of the file to create 
                |         iExtensionType
                |             The extension of the file
                |             Legal values:
                | 
                |                 "xls" for a Microsoft Excel workbook
                |                 "txt" for a text file.

        :param Folder i_folder:
        :param str i_file_name:
        :param str i_extension_type:
        :rtype: None
        """
        return self.analysis_image.ExportData(i_folder.com_object, i_file_name, i_extension_type)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'export_data'
        # # vba_code = """
        # # Public Function export_data(analysis_image)
        # #     Dim iFolder (2)
        # #     analysis_image.ExportData iFolder
        # #     export_data = iFolder
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def export_data_in_any_user_axis(
            self,
            i_folder: Folder,
            i_file_name: str,
            i_extension_type: str,
            i_axis_system: AnyObject,
            i_product: Product,
            i_axis_orientation_type: int,
            i_export_mesh_part_id: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ExportDataInAnyUserAxis(Folder iFolder,
                | CATBSTR iFileName,
                | CATBSTR iExtensionType,
                | AnyObject iAxisSystem,
                | Product iProduct,
                | CATAxisOrientationType iAxisOrientationType,
                | boolean iExportMeshPartID)
                | 
                |     Extracts image results.
                |     The export is done related to an existing image and will be stored in a
                |     CATIA Folder as a Text file or as an Excel file. If User has not implemented
                |     CATIAAxisSystem interface for axis system, but has CATIABase interface
                |     implementation.
                |     Limitations:
                | 
                |         The allowed output positions are: node, element, center of element, and
                |         node of element
                |         The allowed values are: integer, real or double
                |         The allowed value types are: average or discontinuous iso, symbol,
                |         fringe or text
                | 
                |     To export data with mesh-part identification use
                |     ExportDataWithMeshPartId
                | 
                |     Parameters:
                | 
                |         iFolder
                |             The folder to store the file to create 
                |         iFileName
                |             The name of the file to create 
                |         iExtensionType
                |             The extension of the file
                |             Legal values:
                | 
                |                 "xls" for a Microsoft Excel workbook
                |                 "txt" for a text file.
                | 
                |         iAxisSystem
                |             Reference to the axis system to be used for location
                |             transformation. 
                |         iProduct
                |             Reference to the product, where the above axis system is defined.
                |             
                |         iAxisOrientationType
                |             Coordinate system type of location axis system 
                |         iExportMeshPartID
                |             Flag for exporting with meshpartid or not

        :param Folder i_folder:
        :param str i_file_name:
        :param str i_extension_type:
        :param AnyObject i_axis_system:
        :param Product i_product:
        :param int i_axis_orientation_type: enum cat_axis_orientation_type
        :param bool i_export_mesh_part_id:
        :rtype: None
        """
        return self.analysis_image.ExportDataInAnyUserAxis(
            i_folder.com_object,
            i_file_name,
            i_extension_type,
            i_axis_system.com_object,
            i_product.com_object,
            i_axis_orientation_type,
            i_export_mesh_part_id
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'export_data_in_any_user_axis'
        # # vba_code = """
        # # Public Function export_data_in_any_user_axis(analysis_image)
        # #     Dim iFolder (2)
        # #     analysis_image.ExportDataInAnyUserAxis iFolder
        # #     export_data_in_any_user_axis = iFolder
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def export_data_in_global_axis(
            self,
            i_folder: Folder,
            i_file_name: str,
            i_extension_type: str,
            i_axis_orientation_type: int,
            i_export_mesh_part_id: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ExportDataInGlobalAxis(Folder iFolder,
                | CATBSTR iFileName,
                | CATBSTR iExtensionType,
                | CATAxisOrientationType iAxisOrientationType,
                | boolean iExportMeshPartID)
                | 
                |     Extracts image results.
                |     The export is done related to an existing image and will be stored in a
                |     CATIA Folder as a Text file or as an Excel file.
                |     Limitations:
                | 
                |         The allowed output positions are: node, element, center of element, and
                |         node of element
                |         The allowed values are: integer, real or double
                |         The allowed value types are: average or discontinuous iso, symbol,
                |         fringe or text
                | 
                |     Parameters:
                | 
                |         iFolder
                |             The folder to store the file to create 
                |         iFileName
                |             The name of the file to create 
                |         iExtensionType
                |             The extension of the file
                |             Legal values:
                | 
                |                 "xls" for a Microsoft Excel workbook
                |                 "txt" for a text file.
                | 
                |         iAxisOrientationType
                |             Coordinate system type of location axis system 
                |         iExportMeshPartID
                |             Flag for exporting with meshpartid or not

        :param Folder i_folder:
        :param str i_file_name:
        :param str i_extension_type:
        :param int i_axis_orientation_type: enum cat_axis_orientation_type
        :param bool i_export_mesh_part_id:
        :rtype: None
        """
        return self.analysis_image.ExportDataInGlobalAxis(
            i_folder.com_object,
            i_file_name,
            i_extension_type,
            i_axis_orientation_type,
            i_export_mesh_part_id
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'export_data_in_global_axis'
        # # vba_code = """
        # # Public Function export_data_in_global_axis(analysis_image)
        # #     Dim iFolder (2)
        # #     analysis_image.ExportDataInGlobalAxis iFolder
        # #     export_data_in_global_axis = iFolder
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def export_data_in_manual_axis(
            self,
            i_folder: Folder,
            i_file_name: str,
            i_extension_type: str,
            i_origin: tuple,
            i_x_direction: tuple,
            i_y_direction: tuple,
            i_z_direction: tuple,
            i_axis_orientation_type: int,
            i_export_mesh_part_id: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ExportDataInManualAxis(Folder iFolder,
                | CATBSTR iFileName,
                | CATBSTR iExtensionType,
                | CATSafeArrayVariant iOrigin,
                | CATSafeArrayVariant iXDirection,
                | CATSafeArrayVariant iYDirection,
                | CATSafeArrayVariant iZDirection,
                | CATAxisOrientationType iAxisOrientationType,
                | boolean iExportMeshPartID)
                | 
                |     Extracts image results.
                |     The export is done related to an existing image and will be stored in a
                |     CATIA Folder as a Text file or as an Excel file.
                |     Limitations:
                | 
                |         The allowed output positions are: node, element, center of element, and
                |         node of element
                |         The allowed values are: integer, real or double
                |         The allowed value types are: average or discontinuous iso, symbol,
                |         fringe or text
                | 
                |     Parameters:
                | 
                |         iFolder
                |             The folder to store the file to create 
                |         iFileName
                |             The name of the file to create 
                |         iExtensionType
                |             The extension of the file
                |             Legal values:
                | 
                |                 "xls" for a Microsoft Excel workbook
                |                 "txt" for a text file.
                | 
                |         iOrigin
                |             Origin of Location axis system 
                |         iXDirection
                |             co-ordinates of a point on X- axis of Location axis system
                |             
                |         iYDirection
                |             co-ordinates of a point on Y- axis of Location axis system
                |             
                |         iZDirection
                |             co-ordinates of a point on Z- axis of Location axis system
                |             
                |         iAxisOrientationType
                |             Coordinate system type of location axis system 
                |         iExportMeshPartID
                |             Flag for exporting with meshpartid or not

        :param Folder i_folder:
        :param str i_file_name:
        :param str i_extension_type:
        :param tuple i_origin:
        :param tuple i_x_direction:
        :param tuple i_y_direction:
        :param tuple i_z_direction:
        :param int i_axis_orientation_type: enum cat_axis_orientation_type
        :param bool i_export_mesh_part_id:
        :rtype: None
        """
        return self.analysis_image.ExportDataInManualAxis(
            i_folder.com_object,
            i_file_name,
            i_extension_type,
            i_origin,
            i_x_direction,
            i_y_direction,
            i_z_direction,
            i_axis_orientation_type,
            i_export_mesh_part_id
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'export_data_in_manual_axis'
        # # vba_code = """
        # # Public Function export_data_in_manual_axis(analysis_image)
        # #     Dim iFolder (2)
        # #     analysis_image.ExportDataInManualAxis iFolder
        # #     export_data_in_manual_axis = iFolder
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def export_data_in_user_axis(
            self,
            i_folder: Folder,
            i_file_name: str,
            i_extension_type: str,
            i_axis_system: AxisSystem,
            i_product: Product,
            i_axis_orientation_type: int,
            i_export_mesh_part_id: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ExportDataInUserAxis(Folder iFolder,
                | CATBSTR iFileName,
                | CATBSTR iExtensionType,
                | AxisSystem iAxisSystem,
                | Product iProduct,
                | CATAxisOrientationType iAxisOrientationType,
                | boolean iExportMeshPartID)
                | 
                |     Extracts image results.
                |     The export is done related to an existing image and will be stored in a
                |     CATIA Folder as a Text file or as an Excel file.
                |     Limitations:
                | 
                |         The allowed output positions are: node, element, center of element, and
                |         node of element
                |         The allowed values are: integer, real or double
                |         The allowed value types are: average or discontinuous iso, symbol,
                |         fringe or text
                | 
                |     To export data with mesh-part identification use
                |     ExportDataWithMeshPartId
                | 
                |     Parameters:
                | 
                |         iFolder
                |             The folder to store the file to create 
                |         iFileName
                |             The name of the file to create 
                |         iExtensionType
                |             The extension of the file
                |             Legal values:
                | 
                |                 "xls" for a Microsoft Excel workbook
                |                 "txt" for a text file.
                | 
                |         iAxisSystem
                |             Reference to the axis system to be used for location
                |             transformation. 
                |         iProduct
                |             Reference to the product, where the above axis system is defined.
                |             
                |         iAxisOrientationType
                |             Coordinate system type of location axis system 
                |         iExportMeshPartID
                |             Flag for exporting with meshpartid or not

        :param Folder i_folder:
        :param str i_file_name:
        :param str i_extension_type:
        :param AxisSystem i_axis_system:
        :param Product i_product:
        :param int i_axis_orientation_type: enum cat_axis_orientation_type
        :param bool i_export_mesh_part_id:
        :rtype: None
        """
        return self.analysis_image.ExportDataInUserAxis(
            i_folder.com_object,
            i_file_name,
            i_extension_type,
            i_axis_system.com_object,
            i_product.com_object,
            i_axis_orientation_type,
            i_export_mesh_part_id)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'export_data_in_user_axis'
        # # vba_code = """
        # # Public Function export_data_in_user_axis(analysis_image)
        # #     Dim iFolder (2)
        # #     analysis_image.ExportDataInUserAxis iFolder
        # #     export_data_in_user_axis = iFolder
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def export_data_with_mesh_part_id(self, i_folder: Folder, i_file_name: str, i_extension_type: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ExportDataWithMeshPartId(Folder iFolder,
                | CATBSTR iFileName,
                | CATBSTR iExtensionType)
                | 
                |     Extracts image results and location with mesh part name (as
                |     identifier).
                |     The export is done related to an existing image and will be stored in a
                |     CATIA Folder as a Text file or as an Excel file.
                |     Limitations:
                | 
                |         The allowed output positions are: element, center of element, and node
                |         of element
                |         The allowed values are: integer, real or double
                |         The allowed value types are: average or discontinuous iso, symbol,
                |         fringe or text
                | 
                |     To export data with mesh-part identification use
                |     ExportData
                | 
                |     Parameters:
                | 
                |         iFolder
                |             The folder to store the file to create 
                |         iFileName
                |             The name of the file to create 
                |         iExtensionType
                |             The extension of the file
                |             Legal values:
                | 
                |                 "xls" for a Microsoft Excel workbook
                |                 "txt" for a text file.

        :param Folder i_folder:
        :param str i_file_name:
        :param str i_extension_type:
        :rtype: None
        """
        return self.analysis_image.ExportDataWithMeshPartId(i_folder.com_object, i_file_name, i_extension_type)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'export_data_with_mesh_part_id'
        # # vba_code = """
        # # Public Function export_data_with_mesh_part_id(analysis_image)
        # #     Dim iFolder (2)
        # #     analysis_image.ExportDataWithMeshPartId iFolder
        # #     export_data_with_mesh_part_id = iFolder
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def reset_selection(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ResetSelection()
                | 
                |     Resets all selections in an image.
                |     This is done related to an existing image

        :rtype: None
        """
        return self.analysis_image.ResetSelection()

    def set_activation_status(self, i_activation_status: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetActivationStatus(CATVariant iActivationStatus)
                | 
                |     Activates oe deactivates an image.
                |     This is done related to an existing image
                | 
                |     Parameters:
                | 
                |         iActivationStatus
                |             To activate or not the current image.

        :param cat_variant i_activation_status:
        :rtype: None
        """
        return self.analysis_image.SetActivationStatus(i_activation_status)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_activation_status'
        # # vba_code = """
        # # Public Function set_activation_status(analysis_image)
        # #     Dim iActivationStatus (2)
        # #     analysis_image.SetActivationStatus iActivationStatus
        # #     set_activation_status = iActivationStatus
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_current_occurrence(self, i_occurrence_number: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetCurrentOccurrence(CATVariant iOccurrenceNumber)
                | 
                |     Sets occurrence number for an image.
                |     This is done related to an existing image
                | 
                |     Parameters:
                | 
                |         iOccurrenceNumber
                |             The number to select
                |             Legal value: 1 ≤ iOccurrenceNumber ≤ nbOccurrence

        :param cat_variant i_occurrence_number:
        :rtype: None
        """
        return self.analysis_image.SetCurrentOccurrence(i_occurrence_number)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_current_occurrence'
        # # vba_code = """
        # # Public Function set_current_occurrence(analysis_image)
        # #     Dim iOccurrenceNumber (2)
        # #     analysis_image.SetCurrentOccurrence iOccurrenceNumber
        # #     set_current_occurrence = iOccurrenceNumber
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_selection(self, i_reference: Reference, i_replace_mode: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetSelection(Reference iReference,
                | CATVariant iReplaceMode)
                | 
                |     Adds a selection to an image.
                |     This is done related to an existing image
                | 
                |     Parameters:
                | 
                |         iReference
                |             The selectionGroup to add 
                |         iReplaceMode
                |             To replace or not the current selections.

        :param Reference i_reference:
        :param cat_variant i_replace_mode:
        :rtype: None
        """
        return self.analysis_image.SetSelection(i_reference.com_object, i_replace_mode)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_selection'
        # # vba_code = """
        # # Public Function set_selection(analysis_image)
        # #     Dim iReference (2)
        # #     analysis_image.SetSelection iReference
        # #     set_selection = iReference
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def update(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Update()
                | 
                |     Updates an image.
                |     This is done related to an existing image

        :rtype: None
        """
        return self.analysis_image.Update()

    def __repr__(self):
        return f'AnalysisImage(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.arrangement_interfaces.arrangement_contours import ArrangementContours
from pycatia.system_interfaces.any_object import AnyObject


class ArrangementArea(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ArrangementArea
                | 
                | Use this object to access an ArrangementArea object's properties and
                | functions.
                | Role: The ArrangementArea object is a type of Arrangement Object defining an
                | area containing other objects.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.arrangement_area = com_object

    @property
    def arrangement_contours(self) -> ArrangementContours:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ArrangementContours() As ArrangementContours (Read
                | Only)
                | 
                |     Returns the ArrangementContours collection object associated with an
                |     ArrangementArea object.
                | 
                |     Example:
                |         This example retrieves the ArrangementContours collection object for
                |         the objArea1 object.
                | 
                |          Dim objArrContours   As ArrangementContours
                |          Set objArrContours  = objArea1.ArrangementContours

        :rtype: ArrangementContours
        """

        return ArrangementContours(self.arrangement_area.ArrangementContours)

    @property
    def height(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Height() As double
                | 
                |     Returns or sets the Height of an ArrangementArea object.
                | 
                |     Example:
                |         This example retrieves the Height for the objArea1
                |         object.
                | 
                |          Dim dblAreaHeight   As Double
                |          dblAreaHeight  = objArea1.Height

        :rtype: float
        """

        return self.arrangement_area.Height

    @height.setter
    def height(self, value: float):
        """
        :param float value:
        """

        self.arrangement_area.Height = value

    @property
    def size(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Size() As double (Read Only)
                | 
                |     Returns the Size of the ArrangementArea.
                | 
                |     Example:
                |         This example retrieves the Size of the objArea1
                |         object.
                | 
                |          Dim dblAreaSize   As Double
                |          dblAreaSize  = objArea1.Size

        :rtype: float
        """

        return self.arrangement_area.Size

    @property
    def visu_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property VisuMode() As CATArrangementAreaVisuMode
                | 
                |     Returns or sets the Visualization Mode for an ArrangementArea
                |     object.
                | 
                |     Example:
                |         This example sets the Visualization Mode for the objArea1 object to
                |         CatArrangementAreaVisuModeVolume.
                | 
                |          objArea1.VisuMode = CatArrangementAreaVisuModeVolume

        :return: enum cat_arrangement_area_visu_mode
        :rtype: int
        """

        return self.arrangement_area.VisuMode

    @visu_mode.setter
    def visu_mode(self, value: int):
        """
        :param int value: enum cat_arrangement_area_visu_mode
        """

        self.arrangement_area.VisuMode = value

    def get_technological_object(self, i_application_type: str) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTechnologicalObject(CATBSTR iApplicationType) As
                | CATBaseDispatch
                | 
                |     Returns the applicative data whose type is the given
                |     parameter.
                | 
                |     Parameters:
                | 
                |         iApplicationType
                |             The type of applicative data searched. 
                | 
                |     Returns:
                |         oApplicativeObj The matched applicative object.
                | 
                |         Example:
                |             This example retrieves the desired applicative object from the
                |             objArea1 object.
                | 
                |              Dim objProd   As Product
                |              objProd  = objArea1.GetTechnologicalObject("Product")

        :param str i_application_type:
        :rtype: AnyObject
        """
        return self.arrangement_area.GetTechnologicalObject(i_application_type)

    def __repr__(self):
        return f'ArrangementArea(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import TYPE_CHECKING

from pycatia.funct_system_interfaces.functional_element import FunctionalElement
from pycatia.funct_system_interfaces.functional_facet import FunctionalFacet
from pycatia.funct_system_interfaces.functional_facet_mgr import FunctionalFacetMgr
from pycatia.funct_system_interfaces.functional_position import FunctionalPosition

if TYPE_CHECKING:
    from pycatia.funct_system_interfaces.funct_actions_group import FunctActionsGroup


class FunctionalAction(FunctionalElement):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CATFunctSystemItf.FunctionalElement
                |                         FunctionalAction
                | 
                | The interface to access a Functional Action.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.functional_action = com_object

    @property
    def from_(self) -> FunctionalPosition:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property From() As FunctionalPosition
                | 
                |     Get the From object.

        :rtype: FunctionalPosition
        """

        return FunctionalPosition(self.functional_action.From)

    @from_.setter
    def from_(self, value: FunctionalPosition):
        """
        :param FunctionalPosition value:
        """

        self.functional_action.From = value

    @property
    def group(self) -> 'FunctActionsGroup':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Group() As FunctActionsGroup (Read Only)
                | 
                |     Get the Group property.
                | 
                |     Vary when adding/removing the action to/from a group.

        :rtype: FunctActionsGroup
        """

        return FunctActionsGroup(self.functional_action.Group)

    @property
    def orientation_direction(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property OrientationDirection() As
                | CATFunctOrientationDirection
                | 
                |     Get the OrientationDirection property.
                | 
                |     See also:
                |         CATFunctOrientationDirection

        :return: enum cat_funct_orientation_direction
        :rtype: int
        """

        return self.functional_action.OrientationDirection

    @orientation_direction.setter
    def orientation_direction(self, value: int):
        """
        :param int value: enum cat_funct_orientation_direction
        """

        self.functional_action.OrientationDirection = value

    @property
    def to(self) -> FunctionalPosition:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property To() As FunctionalPosition
                | 
                |     Get the To object.

        :rtype: FunctionalPosition
        """

        return FunctionalPosition(self.functional_action.To)

    @to.setter
    def to(self, value: FunctionalPosition):
        """
        :param FunctionalPosition value:
        """

        self.functional_action.To = value

    def get_facet(self, i_fm: FunctionalFacetMgr) -> FunctionalFacet:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetFacet(FunctionalFacetMgr iFM) As FunctionalFacet
                | 
                |     Returns the Facet.

        :param FunctionalFacetMgr i_fm:
        :rtype: FunctionalFacet
        """
        return FunctionalFacet(self.functional_action.GetFacet(i_fm.com_object))

    def get_facet_by_name(self, i_fm: str) -> FunctionalFacet:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetFacetByName(CATBSTR iFM) As FunctionalFacet
                | 
                |     Returns the Facet.

        :param str i_fm:
        :rtype: FunctionalFacet
        """
        return FunctionalFacet(self.functional_action.GetFacetByName(i_fm))

    def invert_direction(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub InvertDirection()
                | 
                |     Invert the action's Direction.
                | 
                |     Fails if the action is included in a group.

        :rtype: None
        """
        return self.functional_action.InvertDirection()

    def search_facet(self, i_fm: FunctionalFacetMgr, i_create_if_necessary: bool) -> FunctionalFacet:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func SearchFacet(FunctionalFacetMgr iFM,
                | boolean iCreateIfNecessary) As FunctionalFacet
                | 
                |     Searches the Facet.

        :param FunctionalFacetMgr i_fm:
        :param bool i_create_if_necessary:
        :rtype: FunctionalFacet
        """
        return FunctionalFacet(self.functional_action.SearchFacet(i_fm.com_object, i_create_if_necessary))

    def search_facet_by_name(self, i_fm: str, i_create_if_necessary: bool) -> FunctionalFacet:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func SearchFacetByName(CATBSTR iFM,
                | boolean iCreateIfNecessary) As FunctionalFacet
                | 
                |     Searches the Facet.

        :param str i_fm:
        :param bool i_create_if_necessary:
        :rtype: FunctionalFacet
        """
        return FunctionalFacet(self.functional_action.SearchFacetByName(i_fm, i_create_if_necessary))

    def __repr__(self):
        return f'FunctionalAction(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_str_functional_interfaces.sfm_member import SFMMember
from pycatia.in_interfaces.reference import Reference


class SFMMemberCurve(SFMMember):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CATStrFunctionalInterfaces.SfmObject
                |                         CATStrFunctionalInterfaces.SfmProfile
                |                            CATStrFunctionalInterfaces.SfmMember
                |                                 SfmMemberCurve
                | 
                | Interface to manage Member created with one curve and a reference
                | surface.
                | Role: To manage member created with one curve and a reference
                | surface.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sfm_member_curve = com_object

    @property
    def curve(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Curve() As Reference
                | 
                |     Returns or sets the curve.
                |     Sub-element(s) supported (see Boundary object): Edge.
                | 
                |     Example:
                |         This example retrieves in Curve the supporting curve for the
                |         SfmMemberCurve feature.
                | 
                |          Dim Curve As Reference
                |          Set Curve = SfmMemberCurve.Curve

        :rtype: Reference
        """

        return Reference(self.sfm_member_curve.Curve)

    @curve.setter
    def curve(self, value: Reference):
        """
        :param Reference value:
        """

        self.sfm_member_curve.Curve = value.com_object

    @property
    def reference_surface(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ReferenceSurface() As Reference
                | 
                |     Returns or sets the reference surface.
                | 
                |     Example:
                |         This example retrieves in ReferenceSurface the reference surface for
                |         the SfmMemberCurve feature.
                | 
                |          Dim ReferenceSurface As Reference
                |          Set ReferenceSurface = SfmMemberCurve.ReferenceSurface

        :rtype: Reference
        """

        return Reference(self.sfm_member_curve.ReferenceSurface)

    @reference_surface.setter
    def reference_surface(self, value: Reference):
        """
        :param Reference value:
        """

        self.sfm_member_curve.ReferenceSurface = value.com_object

    @property
    def reference_surface_orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ReferenceSurfaceOrientation() As long
                | 
                |     Returns or sets the reference surface orientation.
                | 
                |     Example:
                |         This example retrieves in ReferenceSurfaceOrient the reference surface
                |         orientation for SfmMemberCurve feature.
                | 
                |          Dim ReferenceSurfaceOrient As Integer
                |          Set ReferenceSurfaceOrient = SfmMemberCurve.ReferenceSurfaceOrientation

        :rtype: int
        """

        return self.sfm_member_curve.ReferenceSurfaceOrientation

    @reference_surface_orientation.setter
    def reference_surface_orientation(self, value: int):
        """
        :param int value:
        """

        self.sfm_member_curve.ReferenceSurfaceOrientation = value

    def invert_reference_surface(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub InvertReferenceSurface()
                | 
                |     Inverts the reference surface orientation.
                | 
                |     Example:
                |         This example inverts the orientation of the reference surface for the
                |         SfmMemberCurve feature.
                | 
                |          SfmMemberCurve.InvertReferenceSurface

        :rtype: None
        """
        return self.sfm_member_curve.InvertReferenceSurface()

    def __repr__(self):
        return f'SFMMemberCurve(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_plant_ship_interfaces.psp_list_of_bstrs import PSPListOfBSTRs
from pycatia.cat_plant_ship_interfaces.psp_list_of_doubles import PSPListOfDoubles
from pycatia.cat_plant_ship_interfaces.psp_list_of_longs import PSPListOfLongs
from pycatia.knowledge_interfaces.parameter import Parameter
from pycatia.system_interfaces.any_object import AnyObject


class PSPAttribute(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PspAttribute
                | 
                | Represents Attribute Interface to query Plant Ship objects'
                | attributes.
                | Role: To query and reset attributes.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.psp_attribute = com_object

    def get_multi_string_attribute_values(self, i_attribute_name: str) -> PSPListOfBSTRs:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetMultiStringAttributeValues(CATBSTR iAttributeName) As
                | PspListOfBSTRs
                | 
                |     Retrieves String values for the input attribute the type
                |     catPspIDLMultiString.
                | 
                |     Parameters:
                | 
                |         iAttributeName
                |             Attribute Name 
                | 
                |     Returns:
                |         List of string values 
                |     Example:
                | 
                |          Dim objThisIntf As PspAttribute
                |          Dim strVar1 As CATBSTR
                |          Dim objArg2 As PspListOfBSTRs
                |           ...
                |          Set objArg2 = objThisIntf.GetMultiStringAttributeValues (strVar1)

        :param str i_attribute_name:
        :rtype: PSPListOfBSTRs
        """
        return PSPListOfBSTRs(self.psp_attribute.GetMultiStringAttributeValues(i_attribute_name))

    def get_parameter(self, i_attribute_name: str) -> Parameter:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetParameter(CATBSTR iAttributeName) As Parameter
                | 
                |     Retrieve parameter for the input attribute name.
                | 
                |     Parameters:
                | 
                |         iAttributeName
                |             Attribute Name 
                | 
                |     Returns:
                |         Parameter of the attribute 
                |     Example:
                |
                |          Dim objThisIntf As PspAttribute
                |          Dim strVar1 As CATBSTR
                |          Dim ObjVar2 As Parameter
                |           ...
                |          Set objArg2 = objThisIntf.GetParameter (strVar1 )

        :param str i_attribute_name:
        :rtype: Parameter
        """
        return Parameter(self.psp_attribute.GetParameter(i_attribute_name))

    def get_type(self, i_attribute_name: str) -> int:
        """
        .. note::
            :class: toggle
    
            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetType(CATBSTR iAttributeName) As
                | CatPspIDLAttrDataType
                |
                |     Retrieves type of the input attribute. If the type of the attribute is
                |     catPspIDLMultiString use GetMultiStringAttributeValues. for others, use
                |     GetParameter().
                |
                |     Parameters:
                |
                |         iAttributeName
                |             Attribute Name
                |
                |     Returns:
                |         Type of the attribute.
                |     Example:
                |
                |          Dim objThisIntf As PspAttribute
                |          Dim strVar1 As CATBSTR
                |          Dim eType As CatPspIDLAttrDataType
                |
                |           ...
                |          eType = objThisIntf.GetType (strVar1)
        
            :param str i_attribute_name:
            :rtype: enum cat_psp_idl_attr_data_type
            :return: int
            """
        return self.psp_attribute.GetType(i_attribute_name)

    def is_derived(self, i_attribute_name: str) -> bool:
        """
        .. note::
            :class: toggle
    
            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func IsDerived(CATBSTR iAttributeName) As boolean
                |
                |     Retrieve Derived status for the input attribute.
                |
                |     Parameters:
                |
                |         iAttributeName
                |             Attribute Name
                |
                |     Returns:
                |         TRUE if the attribute is derived
                |
                |     Example:
                |
                |          Dim objThisIntf As PspAttribute
                |          Dim strVar1 As CATBSTR
                |          Dim bIsDerived As boolean
                |           ...
                |          bIsDerived = objThisIntf.IsDerived (strVar1)
    
        :param str i_attribute_name:
        :rtype: bool
        """
        return self.psp_attribute.IsDerived(i_attribute_name)

    def is_discrete(self, i_attribute_name: str, ob_status: bool) -> int:
        """
        .. note::
            :class: toggle
    
            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func IsDiscrete(CATBSTR iAttributeName,
                | boolean obStatus) As short
                |
                |     Query whether the input attribute is discrete or not.
                |
                |     Parameters:
                |
                |         iAttributeName
                |             Attribute Name
                |         obStatus
                |             TRUE if attribute is discrete else FALSE
                |
                |     Returns:
                |         Discrete Type value 1-Standard 2-Encoded discrete
                |
                |     Example:
                |
                |          Dim objThisIntf As PspAttribute
                |          Dim strVar1 As CATBSTR
                |          Dim boolVar2 As Boolean
                |          Dim shortVar3  As Short
                |           ...
                |          shortVar3 = objThisIntf.IsDiscrete (strVar1,boolVar2)
    
        :param str i_attribute_name:
        :param bool ob_status:
        :rtype: int
        """
        return self.psp_attribute.IsDiscrete(i_attribute_name, ob_status)

    def list_attributes(self, i_domain_id: int) -> PSPListOfBSTRs:
        """
        .. note::
            :class: toggle
    
            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ListAttributes(CatPspIDLDomainID iDomainID) As
                | PspListOfBSTRs
                |
                |     Retrieves a list of Attributes of an object in the the input domain
                |     ID.
                |
                |     Parameters:
                |
                |         iDomainID
                |             Domain ID. If set to catPspIDLNone, then it will return attributes
                |             in all the domains.
                |
                |     Returns:
                |         List of attributes ( A list of CATIAPspGroupables)
                |
                |     Example:
                |
                |          Dim objThisIntf As PspAttribute
                |          Dim objArg1 As CatPspIDLDomainID
                |          Dim objArg2 As PspListOfBSTRs
                |           ...
                |          Set objArg2 = objThisIntf.ListAttributes (objArg1)
    
        :param int i_domain_id: enum cat_psp_idl_domain_id
        :rtype: PSPListOfBSTRs
        """
        return PSPListOfBSTRs(self.psp_attribute.ListAttributes(i_domain_id))

    def list_double_discrete_values(self, i_attribute_name: str) -> PSPListOfDoubles:
        """
        .. note::
            :class: toggle
    
            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ListDoubleDiscreteValues(CATBSTR iAttributeName) As
                | PspListOfDoubles
                |
                |     Retrieves double discrete values for the input attribute.
                |
                |     Parameters:
                |
                |         iAttributeName
                |             Attribute Name
                |
                |     Returns:
                |         Discrete list of double values
                |
                |     Example:
                |
                |          Dim objThisIntf As PspAttribute
                |          Dim strVar1 As CATBSTR
                |          Dim objArg2 As PspListOfDoubles
                |           ...
                |          Set objArg2 = objThisIntf.ListDoubleDiscreteValues (strVar1 )
    
        :param str i_attribute_name:
        :rtype: PSPListOfDoubles
        """
        return PSPListOfDoubles(self.psp_attribute.ListDoubleDiscreteValues(i_attribute_name))

    def list_encoded_decoded_discrete_values(
            self,
            i_attribute_name: str,
            o_l_discrete_encoded_values: PSPListOfBSTRs,
            o_l_discrete_decoded_value: PSPListOfBSTRs
    ) -> None:
        """
        .. note::
            :class: toggle
    
            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ListEncodedDecodedDiscreteValues(CATBSTR
                | iAttributeName,
                | PspListOfBSTRs oLDiscreteEncodedValues,
                | PspListOfBSTRs oLDiscreteDecodedValue)
                |
                |     Retrieves Encoded-decoded discrete values for the input
                |     attribute.
                |
                |     Parameters:
                |
                |         iAttributeName
                |             Attribute Name
                |         oLDiscreteEncodedValues
                |             Discrete list of encoded string values
                |         oLDiscreteDecodedValue
                |             Discrete list of decoded string values
                |
                |     Example:
                |
                |          Dim objThisIntf As PspAttribute
                |          Dim strVar1 As CATBSTR
                |          Dim objArg2 As PspListOfBSTRs
                |          Dim objArg3 As PspListOfBSTRs
                |           ...
                |          objThisIntf.ListEncodedDecodedDiscreteValues strVar1, objArg2,
                |          objArg3
    
        :param str i_attribute_name:
        :param PSPListOfBSTRs o_l_discrete_encoded_values:
        :param PSPListOfBSTRs o_l_discrete_decoded_value:
        :rtype: None
        """
        return self.psp_attribute.ListEncodedDecodedDiscreteValues(
            i_attribute_name,
            o_l_discrete_encoded_values.com_object,
            o_l_discrete_decoded_value.com_object
        )
        # # # # Autogenerated comment:
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'list_encoded_decoded_discrete_values'
        # # vba_code = """
        # # Public Function list_encoded_decoded_discrete_values(psp_attribute)
        # #     Dim iAttributeName (2)
        # #     psp_attribute.ListEncodedDecodedDiscreteValues iAttributeName
        # #     list_encoded_decoded_discrete_values = iAttributeName
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def list_integer_discrete_values(self, i_attribute_name: str) -> PSPListOfLongs:
        """
        .. note::
            :class: toggle
    
            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ListIntegerDiscreteValues(CATBSTR iAttributeName) As
                | PspListOfLongs
                |
                |     Retrieve integer (long) discrete values for the input
                |     attribute.
                |
                |     Parameters:
                |
                |         iAttributeName
                |             Attribute Name
                |
                |     Returns:
                |         Discrete list of integer values
                |
                |     Example:
                |
                |          Dim objThisIntf As PspAttribute
                |          Dim strVar1 As CATBSTR
                |          Dim objArg2 As PspListOfLongs
                |           ...
                |          Set objArg2 = objThisIntf.ListIntegerDiscreteValues (strVar1)
    
        :param str i_attribute_name:
        :rtype: PSPListOfLongs
        """
        return PSPListOfLongs(self.psp_attribute.ListIntegerDiscreteValues(i_attribute_name))

    def list_string_discrete_values(self, i_attribute_name: str) -> PSPListOfBSTRs:
        """
        .. note::
            :class: toggle
    
            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ListStringDiscreteValues(CATBSTR iAttributeName) As
                | PspListOfBSTRs
                |
                |     RetrievesString discrete values for the input attribute.
                |
                |     Parameters:
                |
                |         iAttributeName
                |             Attribute Name
                |
                |     Returns:
                |         Discrete list of string values
                |
                |     Example:
                |
                |          Dim objThisIntf As PspAttribute
                |          Dim strVar1 As CATBSTR
                |          Dim objArg2 As PspListOfBSTRs
                |           ...
                |          Set objArg2 = objThisIntf.ListStringDiscreteValues (strVar1)
    
        :param str i_attribute_name:
        :rtype: PSPListOfBSTRs
        """
        return PSPListOfBSTRs(self.psp_attribute.ListStringDiscreteValues(i_attribute_name))

    def reset_derived_attr(self, i_attribute_name: str) -> None:
        """
        .. note::
            :class: toggle
    
            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ResetDerivedAttr(CATBSTR iAttributeName)
                |
                |     Reset derived status of the attribute to not-derived.
                |
                |     Parameters:
                |
                |         iAttributeName
                |             Attribute Name
                |
                |     Example:
                |
                |          Dim objThisIntf As PspAttribute
                |          Dim strVar1 As CATBSTR
                |           ...
                |          objThisIntf.ResetDerivedAttr strVar1
    
        :param str i_attribute_name:
        :rtype: None
        """
        return self.psp_attribute.ResetDerivedAttr(i_attribute_name)

    def __repr__(self):
        return f'PSPAttribute(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.funct_system_interfaces.funct_script import FunctScript
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class FunctScripts(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     FunctScripts
                | 
                | The interface to access a set of Functional Scripts.
                | 
                | It is managed on a Functional Element, thru the GenerativeKnowledge Facet
                | Manager (GKW).
    
    """

    def __init__(self, com_object, child_object=FunctScript):
        super().__init__(com_object, child_object=FunctScript)
        self.funct_scripts = com_object
        self.child_object = child_object

    def create(self, i_name: str) -> FunctScript:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Create(CATBSTR iName) As FunctScript
                | 
                |     Create a FunctScript.

        :param str i_name:
        :rtype: FunctScript
        """
        return FunctScript(self.funct_scripts.Create(i_name))

    def delete(self, i_script: FunctScript) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Delete(FunctScript iScript)
                | 
                |     Delete a FunctScript.

        :param FunctScript i_script:
        :rtype: None
        """
        return self.funct_scripts.Delete(i_script.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'delete'
        # # vba_code = """
        # # Public Function delete(funct_scripts)
        # #     Dim iScript (2)
        # #     funct_scripts.Delete iScript
        # #     delete = iScript
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def elem(self, i_index: cat_variant) -> FunctScript:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Elem(CATVariant iIndex) As FunctScript
                | 
                |     Returns an association using its index or its name from the Scripts
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Script to retrieve from the collection
                |             of Scripts. As a numerics, this index is the rank of the Script in the
                |             collection. The index of the first Script in the collection is 1, and the index
                |             of the last Script is Count. As a string, it is the name you assigned to the
                |             Script using the 
                | 
                |         AnyObject.Name property. 
                |     Returns:
                |         The retrieved Script 
                |     Example:
                |         This example retrieves in Act1 the fifth Script in the collection and
                |         in Act2 the Script named Moves.
                | 
                |          Dim FunctElem As FunctionalObject
                |          Set FunctElem = FunctDoc.CurrentDescription.Objects.Elem("Valve")
                |          Dim FacetGKW As FunctionalGenScriptMgr
                |          Set FacetGKW = FunctElem.GetFacetByName("GKW")
                |          Dim Assoc1 As FunctScript
                |          Set Assoc1 = FacetGKW.Scripts.Elem(5)
                |          Dim Assoc2 As FunctScript
                |          Set Assoc2 = FacetGKW.Scripts.Elem("Producing the Skeleton 2D")

        :param cat_variant i_index:
        :rtype: FunctScript
        """
        return FunctScript(self.funct_scripts.Elem(i_index))

    def __repr__(self):
        return f'FunctScripts(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_boundary_conditions import ABQBoundaryConditions
from pycatia.abq_automation_interfaces.abq_fields import ABQFields
from pycatia.abq_automation_interfaces.abq_loads import ABQLoads
from pycatia.abq_automation_interfaces.abq_step import ABQStep


class ABQGeneralStaticStep(ABQStep):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQAutomationItf.ABQStep
                |                         ABQGeneralStaticStep
                | 
                | Represents an Abaqus general static step (ABQGeneralStaticStep)
                | object.
                | Role: Access an Abaqus general static step object or determine its
                | properties.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abq_general_static_step = com_object

    @property
    def boundary_conditions(self) -> ABQBoundaryConditions:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property BoundaryConditions() As ABQBoundaryConditions (Read
                | Only)
                | 
                |     Returns the ABQBoundaryConditions container associated with the
                |     step.
                | 
                |     Example:
                |         This example retrieves the ABQBoundaryConditions container
                |         abqBCs.
                | 
                |          Dim abqGenStep As ABQGeneralStaticStep 
                |          Dim abqBCs As ABQBoundaryConditions
                |          Set abqBCs = abqGenStep.BoundaryConditions

        :rtype: ABQBoundaryConditions
        """

        return ABQBoundaryConditions(self.abq_general_static_step.BoundaryConditions)

    @property
    def description(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Description() As CATBSTR
                | 
                |     Returns or sets the description of the Abaqus general static
                |     step.
                | 
                |     Returns:
                |         The description of the Abaqus general static step.

        :rtype: str
        """

        return self.abq_general_static_step.Description

    @description.setter
    def description(self, value: str):
        """
        :param str value:
        """

        self.abq_general_static_step.Description = value

    @property
    def energy_fraction(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property EnergyFraction() As double
                | 
                |     Returns or sets the EnergyFraction if the stabilization method is
                |     DISSIPATION.
                | 
                |     Returns:
                |         The energy fraction.

        :rtype: float
        """

        return self.abq_general_static_step.EnergyFraction

    @energy_fraction.setter
    def energy_fraction(self, value: float):
        """
        :param float value:
        """

        self.abq_general_static_step.EnergyFraction = value

    @property
    def fields(self) -> ABQFields:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Fields() As ABQFields (Read Only)
                | 
                |     Returns the ABQFields container associated with the step.
                | 
                |     Example:
                |         This example retrieves the ABQFields container
                |         abqFields.
                | 
                |          Dim abqGenStep As ABQGeneralStaticStep 
                |          Dim abqFields As ABQFields
                |          Set abqFields = abqGenStep.Fields

        :rtype: ABQFields
        """

        return ABQFields(self.abq_general_static_step.Fields)

    @property
    def initial_inc(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property InitialInc() As double
                | 
                |     Returns or sets the size of the initial increment.
                | 
                |     Returns:
                |         The initial increment size.

        :rtype: float
        """

        return self.abq_general_static_step.InitialInc

    @initial_inc.setter
    def initial_inc(self, value: float):
        """
        :param float value:
        """

        self.abq_general_static_step.InitialInc = value

    @property
    def loads(self) -> ABQLoads:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Loads() As ABQLoads (Read Only)
                | 
                |     Returns the ABQLoads container associated with the step.
                | 
                |     Example:
                |         The following example retrieves the ABQLoads container
                |         abqLoads:
                | 
                |          Dim abqGenStep As ABQGeneralStaticStep 
                |          Dim abqLoads As ABQLoads
                |          Set abqLoads = abqGenStep.Loads

        :rtype: ABQLoads
        """

        return ABQLoads(self.abq_general_static_step.Loads)

    @property
    def max_inc(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MaxInc() As double
                | 
                |     Returns or sets the maximum increment if the type of the incrementation is
                |     set to AUTO_INCREMENT.
                | 
                |     Returns:
                |         The maximum increment.

        :rtype: float
        """

        return self.abq_general_static_step.MaxInc

    @max_inc.setter
    def max_inc(self, value: float):
        """
        :param float value:
        """

        self.abq_general_static_step.MaxInc = value

    @property
    def max_num_inc(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MaxNumInc() As short
                | 
                |     Returns or sets the maximum number of increments if the type of the
                |     incremention is set to AUTO_INCREMENT.
                | 
                |     Returns:
                |         The maximum number of increments.

        :rtype: int
        """

        return self.abq_general_static_step.MaxNumInc

    @max_num_inc.setter
    def max_num_inc(self, value: int):
        """
        :param int value:
        """

        self.abq_general_static_step.MaxNumInc = value

    @property
    def min_inc(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MinInc() As double
                | 
                |     Returns or sets the minimum increment if the type of the incrementation is
                |     set to AUTO_INCREMENT.
                | 
                |     Returns:
                |         The minimum increment.

        :rtype: float
        """

        return self.abq_general_static_step.MinInc

    @min_inc.setter
    def min_inc(self, value: float):
        """
        :param float value:
        """

        self.abq_general_static_step.MinInc = value

    @property
    def nl_geom(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NLGeom() As boolean
                | 
                |     Returns or sets whether the geometry remains linear during the analysis. A
                |     value of true indicates that the geometry remains linear.
                | 
                |     Returns:
                |         A boolean specifying whether the geometry remains linear during the
                |         analysis.

        :rtype: bool
        """

        return self.abq_general_static_step.NLGeom

    @nl_geom.setter
    def nl_geom(self, value: bool):
        """
        :param bool value:
        """

        self.abq_general_static_step.NLGeom = value

    @property
    def stabilization(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Stabilization() As boolean (Read Only)
                | 
                |     Returns a boolean indicating whether the stabilization option was
                |     selected.
                | 
                |     Returns:
                |         The stabilization status. 
                |     Example:
                |         The following example returns the status of the stabilization option
                |         bFlag in the general static step generalstaticstep.
                | 
                |          Dim generalstaticstep As ABQGeneralStaticStep
                |          Dim bFlag As boolean
                |          Set bFlag =  generalstaticstep.Stabilization

        :rtype: bool
        """

        return self.abq_general_static_step.Stabilization

    @property
    def stabilization_magnitude(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property StabilizationMagnitude() As double
                | 
                |     Sets and Returns the damping factor if the stabilization method is
                |     FACTOR.
                | 
                |     Returns:
                |         The damping factor.

        :rtype: float
        """

        return self.abq_general_static_step.StabilizationMagnitude

    @stabilization_magnitude.setter
    def stabilization_magnitude(self, value: float):
        """
        :param float value:
        """

        self.abq_general_static_step.StabilizationMagnitude = value

    @property
    def stabilization_method(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property StabilizationMethod() As Stabilization_Type
                | 
                |     Returns or sets the stabilization method if the Stabilization option is
                |     selected.
                | 
                |     Returns:
                |         The stabilization method
                | 
                |           
                |         Legal values:
                |           DISSIPATION
                |           FACTOR

        :rtype: enum stabilization_type
        :rtype: int
        """

        return self.abq_general_static_step.StabilizationMethod

    @stabilization_method.setter
    def stabilization_method(self, value: int):
        """
        :param int value: enum stabilization_type
        """

        self.abq_general_static_step.StabilizationMethod = value

    @property
    def time_incrementation_method(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TimeIncrementationMethod() As Incrementation_Type
                | 
                |     Returns or sets the type of the incrementation during the
                |     step.
                | 
                |     Returns:
                |         The type of the incrementation.
                | 
                |           
                |         Legal values:
                |           AUTO_INCREMENT
                |           FIXED_INCREMENT

        :return: enum incrementation_type
        :rtype: int
        """

        return self.abq_general_static_step.TimeIncrementationMethod

    @time_incrementation_method.setter
    def time_incrementation_method(self, value: int):
        """
        :param int value: enum incrementation_type
        """

        self.abq_general_static_step.TimeIncrementationMethod = value

    @property
    def time_period(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TimePeriod() As double
                | 
                |     Returns or sets the total time period of the Abaqus general static
                |     step.
                | 
                |     Returns:
                |         The total time period of the Abaqus general static step.

        :rtype: float
        """

        return self.abq_general_static_step.TimePeriod

    @time_period.setter
    def time_period(self, value: float):
        """
        :param float value:
        """

        self.abq_general_static_step.TimePeriod = value

    def __repr__(self):
        return f'ABQGeneralStaticStep(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dmaps_interfaces.resource import Resource
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class ResourceCollection(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     ResourceCollection
                | 
                | Interface representing collection of Resources.
                | 
                | Role: Components that implement CATIAResourceCollection are
                | ...
                | 
                | Do not use the CATIAResourceCollection interface for such and such
                | ClassReference, Class#MethodReference, #InternalMethod...
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.resource_collection = com_object

    def item(self, i_index: cat_variant) -> Resource:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As Resource
                | 
                |     This method gets the specified resource from the given resource collection
                |     management.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The resource identifier 
                | 
                |     Returns:
                |         oResource The resource

        :param cat_variant i_index:
        :rtype: Resource
        """
        return Resource(self.resource_collection.Item(i_index))

    def __repr__(self):
        return f'ResourceCollection(name="{self.name}")'
